@@ -5,10 +5,10 @@ from .hf_datasets_search import hf_datasets_search
 from .s2_citations import s2_get_references, s2_get_citations
 from .document_qa import document_qa
 from .latex import (
-    compile_latex_from_file,
-    compile_latex_from_str,
+    compile_latex,
     get_latex_template,
     get_latex_templates_list,
+    read_pdf,
 )
 from .web_search import web_search, tavily_web_search, exa_web_search, brave_web_search
 from .visit_webpage import visit_webpage
@@ -23,8 +23,7 @@ __all__ = [
     "s2_get_citations",
     "hf_datasets_search",
     "document_qa",
-    "compile_latex_from_file",
-    "compile_latex_from_str",
+    "compile_latex",
     "get_latex_template",
     "get_latex_templates_list",
     "web_search",
@@ -37,4 +36,5 @@ __all__ = [
     "score_research_proposals",
     "review_pdf_paper",
     "download_pdf_paper",
+    "read_pdf",
 ]
